cubepod_async library

Classes

AsyncSignal<T>
AsyncState<T>
AsyncStreamSignal<T>
CancellationToken
A token that can be passed to asynchronous operations to signal cancellation.
ExponentialRetryPolicy
A retry policy that exponentially increases the delay between attempts.
LinearRetryPolicy
A retry policy that waits for a fixed delay between attempts.
RetryPolicy
Defines a strategy for retrying failed asynchronous operations.

Enums

AsyncStatus

Extensions

AsyncSignalExtensions on AsyncSignal<T>
SignalDebounceExt on Signal<T>
Adds debouncing and throttling capabilities to Signal.

Exceptions / Errors

CancelledException
An exception thrown when an operation is cancelled via CancellationToken.